@@ -10,29 +10,29 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.9-78.9AXS2.src.rpm ]
+if [ ! -r kernel-2.6.9-78.14AXS2.src.rpm ]
 then
-    wget http://ftp.miraclelinux.com/pub/Miracle/ia32/standard/4.0/updates/SRPMS/kernel-2.6.9-78.9AXS2.src.rpm || die "Can't download source package."
+    wget http://ftp.miraclelinux.com/pub/Miracle/ia32/standard/4.0/updates/SRPMS/kernel-2.6.9-78.14AXS2.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-2.6.9-78.9AXS2.src.rpm || die "Can't install source package."
+rpm -ivh kernel-2.6.9-78.14AXS2.src.rpm || die "Can't install source package."
 
 cd /usr/src/asianux/SOURCES/ || die "Can't chdir to /usr/src/asianux/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.7-20090401.tar.gz ]
+if [ ! -r ccs-patch-1.6.8-20090824.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.7-20090401.tar.gz || die "Can't download patch."
+    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.8-20090824.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 cp -p /usr/src/asianux/SPECS/kernel-2.6.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-2.6.spec	2009-02-03 18:59:34.000000000 +0900
-+++ kernel-2.6.spec	2009-02-12 16:19:13.000000000 +0900
+--- kernel-2.6.spec	2009-07-16 15:22:03.000000000 +0900
++++ kernel-2.6.spec	2009-08-09 19:36:35.000000000 +0900
 @@ -34,7 +34,7 @@
  #
  %define axbsys %([ "%{?WITH_LKST}" -eq 0 ] && echo || echo .lkst)
  %define dist AXS2
--%define release 78.9%{?dist}%{axbsys}
-+%define release 78.9%{?dist}%{axbsys}_tomoyo_1.6.7
+-%define release 78.14%{?dist}%{axbsys}
++%define release 78.14%{?dist}%{axbsys}_tomoyo_1.6.8p1
  %define sublevel 9
  %define kversion 2.6.%{sublevel}
  %define rpmversion 2.6.%{sublevel}
@@ -55,18 +55,18 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  Version: %{rpmversion}
-@@ -5193,6 +5196,10 @@
+@@ -5241,6 +5244,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.7-20090401.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.6.8-20090824.tar.gz
 +patch -sp1 < patches/ccs-patch-2.6.9-asianux-2.diff
 +
  cp %{SOURCE10} Documentation/
  
  mkdir configs
-@@ -5204,6 +5211,9 @@
+@@ -5252,6 +5259,9 @@
  for i in *.config 
  do 
  	mv $i .config 
